# please check if atlas is enabled or not in numpy
# it's better to be in sync with numpy
# latest atlas (3.10.2) seems to not work correctly with scipy
%define enable_atlas 0

# allow pythran to be disabled in order allow bootstraping
# since pythran requires scipy
%bcond_with pythran

#(eatdirt) Requires a python-numpydoc which is currently broken
%define enable_doc 0

# disable test on build system to speed build
# but they where ok on local iurt build
%define enable_test 0

%define pypi_name	scipy

%define Werror_cflags %nil

%global _disable_ld_no_undefined 1

Summary:	Scientific tools for Python
Name:		python-%{pypi_name}
Group:		Development/Python
Version:	1.14.1
Release:	%mkrel 4
License:	BSD and Boost and Public Domain
Url:		https://pypi.org/project/scipy/
Source0:	%{pypi_source}

BuildRequires:	pyproject-rpm-macros
BuildRequires:	swig
BuildRequires:	patchelf
%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif
BuildRequires:	lapack-devel
BuildRequires:	gcc-gfortran >= 4.0
BuildRequires:	pkgconfig(netcdf)
BuildRequires:	suitesparse-devel
%if %enable_doc
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(matplotlib)
BuildRequires:	python3dist(numpydoc)
%endif

BuildRequires:	pybind11-devel
BuildRequires:	python3-devel
BuildRequires:	python3-numpy-f2py
BuildRequires:	python3-numpy-devel >= 1.9.2
BuildRequires:	python3dist(pybind11) >= 2.4.0
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(cython)
BuildRequires:	python3dist(pythran)
BuildRequires:  python3dist(meson-python)

%description
SciPy is an open source library of scientific tools for Python. SciPy
supplements the popular numpy module, gathering a variety of high
level science and engineering modules together as a single
package. SciPy includes modules for graphics and plotting,
optimization, integration, special functions, signal and image
processing, genetic algorithms, ODE solvers, and others.

%package -n python3-scipy
Summary:	Scipy: Scientific Tools for Python
Group:		Development/Python
%{?python_provide:%python_provide python3-scipy}
Requires:	python3dist(numpy)
Requires:	python3-numpy-f2py

%description -n python3-scipy
Scipy is open-source software for mathematics, science, and
engineering. The core library is NumPy which provides convenient and
fast N-dimensional array manipulation. The SciPy library is built to
work with NumPy arrays, and provides many user-friendly and efficient
numerical routines such as routines for numerical integration and
optimization. Together, they run on all popular operating systems, are
quick to install, and are free of charge. NumPy and SciPy are easy to
use, but powerful enough to be depended upon by some of the world's
leading scientists and engineers.

%if %enable_doc
%package doc
Summary:	Documentation for scipy
Group:		Development/Python
BuildArch:	noarch

%description doc
This package contains documentation for Scipy
%endif

%prep
%autosetup -n %{pypi_name}-%{version} -p1

%if %{without pythran}
# Remove pythran dependency if not explicitly required
sed -i '/pythran/d' pyproject.toml	
%else
# Relax it otherwise
sed -i 's/pythran>=0.12.0,<0.15.0/pythran>=0.12.0/' pyproject.toml	
%endif

cat > site.cfg << EOF
[amd]
library_dirs = %{_libdir}
include_dirs = %{_includedir}/suitesparse
amd_libs = amd

[umfpack]
library_dirs = %{_libdir}
include_dirs = %{_includedir}/suitesparse
umfpack_libs = umfpack
EOF

cat >> pyproject.toml << EOF

[tool.meson-python.args]
setup = ['-Dblas=blas', '-Dlapack=lapack'%{!?with_pythran:, '-Duse-pythran=false'}]
EOF

%generate_buildrequires
%pyproject_buildrequires -R

%build
# Include -fPIE into LDFLAGS to avoid build break with gfortran
LDFLAGS="${LDFLAGS} -fPIE" %pyproject_wheel

%install
%pyproject_install
%pyproject_save_files scipy

# Some files got ambiguous python shebangs, we fix them after everything else is done
%py3_shebang_fix %{buildroot}%{python3_sitearch}

# Remove doc files that should be in %%doc:
%__rm -f %{buildroot}%{python3_sitearch}/%{pypi_name}/*.txt

%if %enable_doc
pushd doc
PYTHONPATH=%{buildroot}%{python3_sitearch}:%{python3_sitearch}:%{python3_sitelib} %__make html
popd
%endif

%if %enable_test
%check
mkdir test
cd test
PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitearch} %{__python3} -c "import scipy; scipy.test('full')"
%endif

%files -n python3-scipy -f %{pyproject_files}
%doc LICENSE.txt

%if %enable_doc
%files doc
%doc doc/build/html/*
%endif


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 1.14.1-4.mga10
+ Revision: 2241083
- Mageia 10 Mass Rebuild

* Sun Mar 02 2025 wally <wally> 1.14.1-3.mga10
+ Revision: 2158226
- rebuild for python3.13

* Wed Sep 11 2024 joequant <joequant> 1.14.1-2.mga10
+ Revision: 2095066
- update to 1.14.1 and numpy2
  rebuild with pytran to bootstrap
- fix typo
- rebuild for numpy 2

* Sun Dec 24 2023 wally <wally> 1.11.4-1.mga10
+ Revision: 2021156
- new version 1.11.4
+ joequant <joequant>
- rebuild for py3.12
+ papoteur <papoteur>
- Mass Rebuild - Python 3.12

* Sat Sep 10 2022 wally <wally> 1.9.1-2.mga9
+ Revision: 1886482
- fix 'ModuleNotFoundError: No module named 'scipy.signal._spline'' error when trying to do 'from scipy import signal'
- build using system python3-pythran

* Thu Sep 08 2022 neoclust <neoclust> 1.9.1-1.mga9
+ Revision: 1885813
- Rediff patch + add more parts for building
- New version 1.9.1

* Mon Apr 04 2022 umeabot <umeabot> 1.7.3-3.mga9
+ Revision: 1842954
- Mageia 9 Mass Rebuild

* Sat Feb 12 2022 tv <tv> 1.7.3-2.mga9
+ Revision: 1773456
- Rebuild for python-3.10

* Sat Jan 22 2022 wally <wally> 1.7.3-1.mga9
+ Revision: 1769451
- new version 1.7.3

* Tue Aug 03 2021 luigiwalser <luigiwalser> 1.6.2-1.mga9
+ Revision: 1738769
- 1.6.2

* Sat Mar 20 2021 guillomovitch <guillomovitch> 1.6.1-1.mga9
+ Revision: 1706123
- new version 1.6.1

* Sat Nov 14 2020 philippem <philippem> 1.5.4-1.mga8
+ Revision: 1645912
- update to 1.5.4

* Thu Oct 01 2020 wally <wally> 1.5.2-2.mga8
+ Revision: 1631464
- rebuild for arm

* Tue Sep 29 2020 wally <wally> 1.5.2-1.mga8
+ Revision: 1631221
- new version 1.5.2
- build using our %%ldflags
- fix linking

* Thu Aug 20 2020 joequant <joequant> 1.3.1-3.mga8
+ Revision: 1616777
- fix python3 shebangs
- fix gcc10 build
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sun Sep 15 2019 wally <wally> 1.3.1-1.mga8
+ Revision: 1441544
- new version 1.3.1
- drop python2 support

* Mon Jan 07 2019 shlomif <shlomif> 1.2.0-1.mga7
+ Revision: 1350420
- Rebuild for python3 3.7

* Sun Sep 23 2018 umeabot <umeabot> 1.1.0-2.mga7
+ Revision: 1300592
- Mageia 7 Mass Rebuild

* Fri Aug 03 2018 eatdirt <eatdirt> 1.1.0-1.mga7
+ Revision: 1247083
- Upgrade to version 1.1.0
+ daviddavid <daviddavid>
- use new python provides

* Fri Oct 13 2017 joequant <joequant> 1.0.0rc1-0.1.mga7
+ Revision: 1171587
- fix version
- upgrade to 1.0.0rc1

* Wed Sep 13 2017 tv <tv> 0.19.1-2.mga7
+ Revision: 1153441
- add missing provides thus fixing tons of deps

* Sat Sep 09 2017 joequant <joequant> 0.19.1-1.mga7
+ Revision: 1152234
- upgrade to 0.19.1

* Sat Sep 09 2017 joequant <joequant> 0.17.1-6.mga7
+ Revision: 1152200
- update with gcc7/binutils

* Sun Aug 06 2017 philippem <philippem> 0.17.1-5.mga7
+ Revision: 1137699
- enable doc, texlive is ok
- enable doc, texlive is ok

* Sun Aug 06 2017 philippem <philippem> 0.17.1-4.mga7
+ Revision: 1137628
- disable doc, texlive is broken
+ pterjan <pterjan>
- Rebuild for python 3.6

* Thu May 26 2016 philippem <philippem> 0.17.1-3.mga6
+ Revision: 1018671
- disable test on build system to speed build but they where ok on local iurt build
- disable atlas as in numpy, enable doc and tests

* Tue May 24 2016 philippem <philippem> 0.17.1-2.mga6
+ Revision: 1018129
- rebuild without tests for arm

* Mon May 23 2016 philippem <philippem> 0.17.1-1.mga6
+ Revision: 1018037
- update to 0.17.1, disable doc, enable tests
+ joequant <joequant>
- rebuild with new atlas and blas
+ tv <tv>
- rebuild for new atlas

* Sun Feb 28 2016 philippem <philippem> 0.17.0-2.mga6
+ Revision: 980379
- rebuild with new python macros
- update to 0.17.0

* Thu Jan 28 2016 barjac <barjac> 0.16.1-2.mga6
+ Revision: 928439
- rebuild for arm

* Wed Oct 28 2015 joequant <joequant> 0.16.1-1.mga6
+ Revision: 895980
- upgrade to 0.16.1 and fix requires

* Thu Oct 08 2015 tv <tv> 0.16.0-4.mga6
+ Revision: 887728
- rebuild for python 3.5

* Thu Oct 08 2015 joequant <joequant> 0.16.0-3.mga6
+ Revision: 887622
- add rtd theme
- upgrade to python 3.5

* Sat Sep 19 2015 philippem <philippem> 0.16.0-2.mga6
+ Revision: 881355
- build with gcc5

* Sat Aug 08 2015 joequant <joequant> 0.16.0-1.mga6
+ Revision: 861683
- upgrade to 0.16.0

* Wed Jul 01 2015 joequant <joequant> 0.15.1-1.mga6
+ Revision: 849314
- upgrade 0.15.1

* Wed Oct 15 2014 umeabot <umeabot> 0.14.0-5.mga5
+ Revision: 743777
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.14.0-4.mga5
+ Revision: 729721
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Tue Aug 19 2014 philippem <philippem> 0.14.0-2.mga5
+ Revision: 665621
- add doc subpackage, disable tests on BS (ok locally under iurt)

* Wed Jul 16 2014 philippem <philippem> 0.14.0-1.mga5
+ Revision: 653310
- update to 0.14.0

* Sat May 31 2014 pterjan <pterjan> 0.13.3-2.mga5
+ Revision: 629001
- Rebuild for new Python

* Fri Mar 07 2014 philippem <philippem> 0.13.3-1.mga5
+ Revision: 601063
- update to 0.13.3

* Tue Nov 19 2013 philippem <philippem> 0.13.0-4.mga4
+ Revision: 551935
- add requires on python-devel

* Wed Nov 13 2013 philippem <philippem> 0.13.0-3.mga4
+ Revision: 551061
- add missing requires

* Fri Nov 01 2013 philippem <philippem> 0.13.0-2.mga4
+ Revision: 548720
- add missing requires

* Tue Oct 29 2013 philippem <philippem> 0.13.0-1.mga4
+ Revision: 547868
- Update to 0.13.0
- Update to 0.13.0

* Tue Oct 22 2013 umeabot <umeabot> 0.12.0-5.mga4
+ Revision: 546139
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 philippem <philippem> 0.12.0-4.mga4
+ Revision: 502197
- fix dependencies

* Tue Oct 15 2013 pterjan <pterjan> 0.12.0-3.mga4
+ Revision: 499335
- Rebuild to add different pythonegg provides for python 2 and 3
+ philippem <philippem>
- cleaning spec

* Mon Jul 01 2013 philippem <philippem> 0.12.0-1.mga4
+ Revision: 449510
- fix group, add Python 3 tests
- add python 3
- update to 0.12.0

* Fri Mar 29 2013 eatdirt <eatdirt> 0.9.0-6.mga3
+ Revision: 406070
- Remove dependence to ATLAS, fix compilation failure

* Sun Jan 13 2013 umeabot <umeabot> 0.9.0-5.mga3
+ Revision: 379476
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 barjac <barjac> 0.9.0-4.mga3
+ Revision: 334137
- rebuild for new umfpack
- spec clean

* Tue Jun 21 2011 ahmad <ahmad> 0.9.0-3.mga2
+ Revision: 110919
- Rebuild against the new umfpack lib major

* Tue May 10 2011 ahmad <ahmad> 0.9.0-2.mga1
+ Revision: 96865
- Drop old/unneeded scriptlets
- Drop the buildroot declaration
- imported package python-scipy


* Mon Feb 28 2011 Lev Givon <lev@mandriva.org> 0.9.0-1mdv2011.0
+ Revision: 641031
- Update to 0.9.0.
  Remove patches that are no longer needed.

* Wed Nov 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 0.8.0-2mdv2011.0
+ Revision: 593008
- Update for python 2.7.

* Wed Jul 28 2010 Lev Givon <lev@mandriva.org> 0.8.0-1mdv2011.0
+ Revision: 562117
- Update to 0.8.0.
  Remove old patches that are no longer necessary.
  Build documentation.

* Mon May 17 2010 Paulo Andrade <pcpa@mandriva.com.br> 0.7.2-2mdv2010.1
+ Revision: 545054
- Correct several sagemath doctest failures - upstream changeset 5790

* Thu Apr 22 2010 Lev Givon <lev@mandriva.org> 0.7.2-1mdv2010.1
+ Revision: 537983
- Update to 0.7.2.

* Tue Mar 23 2010 Lev Givon <lev@mandriva.org> 0.7.1-6mdv2010.1
+ Revision: 526950
- Byte-compile py files.

* Mon Mar 22 2010 Lev Givon <lev@mandriva.org> 0.7.1-5mdv2010.1
+ Revision: 526537
- Obsolete python-symeig (integrated into scipy 0.7.*).

* Thu Feb 04 2010 Paulo Andrade <pcpa@mandriva.com.br> 0.7.1-4mdv2010.1
+ Revision: 500968
- Rebuild

* Mon Jan 25 2010 Lev Givon <lev@mandriva.org> 0.7.1-3mdv2010.1
+ Revision: 496472
- Clean up spec file.
  Build against atlas instead of netlib blas/lapack.

* Tue Oct 06 2009 Lev Givon <lev@mandriva.org> 0.7.1-1mdv2010.0
+ Revision: 455040
- Update to 0.7.1.
- Add python-nose as an optional install dependency.

* Fri May 08 2009 Lev Givon <lev@mandriva.org> 0.7.0-2mdv2010.0
+ Revision: 373544
- Bump release - need to rebuild to run on Mandriva 2009.1.

* Thu Feb 12 2009 Lev Givon <lev@mandriva.org> 0.7.0-1mdv2009.1
+ Revision: 339808
- Update to 0.7.0.

* Mon Jul 14 2008 Funda Wang <fwang@mandriva.org> 0.6.0-8mdv2009.0
+ Revision: 234449
- rebuild for new lapack layout

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 0.6.0-7mdv2009.0
+ Revision: 222523
+ rebuild (emptylog)

* Mon Jun 16 2008 Lev Givon <lev@mandriva.org> 0.6.0-6mdv2009.0
+ Revision: 220136
- Rebuild against numpy 1.1.0.
  Disable netcdf sandbox package because it doesn't compile properly.

* Thu Jan 03 2008 Lev Givon <lev@mandriva.org> 0.6.0-5mdv2008.1
+ Revision: 141003
- Specify amd-devel and umfpack-devel versions to enable build of 0.6.0
  on 2008.0.

* Tue Jan 01 2008 Lev Givon <lev@mandriva.org> 0.6.0-4mdv2008.1
+ Revision: 140144
- Tweak buildreqs in light of the refactored suitesparse packages.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Nov 13 2007 Lev Givon <lev@mandriva.org> 0.6.0-3mdv2008.1
+ Revision: 108470
- Bump release to rebuild against lapack 3.1.1.
- Add patch to allow python-scipy to build against umfpack 5.
- Update to 0.6.0.

* Wed Aug 22 2007 Lev Givon <lev@mandriva.org> 0.5.2.1-1mdv2008.0
+ Revision: 69187
- Update to 0.5.2.1.

* Wed Jun 20 2007 Lev Givon <lev@mandriva.org> 0.5.2-6mdv2008.0
+ Revision: 41866
- Apply patches to allow 0.5.2 to build against numpy 1.0.3.

* Wed Apr 18 2007 Lev Givon <lev@mandriva.org> 0.5.2-5mdv2008.0
+ Revision: 14357
- Bump release to force build against numpy 1.0.2.


* Wed Feb 21 2007 Lev Givon <lev@mandriva.org> 0.5.2-4mdv2007.0
+ Revision: 123942
- Fix python issue in montecarlo.py
- Add netcdf-devel build dependency.
- Tweak.
- Add X11 build dependency for xplt.
- Add randomkit so that the montecarlo package can be built.
- Enable various sandbox packages.
- Add numpy install dependency.

* Thu Dec 14 2006 Lev Givon <lev@mandriva.org> 0.5.2-2mdv2007.1
+ Revision: 97096
- Add swig dependency.
- Add umfpack dependency.

* Sun Dec 10 2006 Lev Givon <lev@mandriva.org> 0.5.2-1mdv2007.1
+ Revision: 94423
- Update to version 0.5.2.
- Raise release number to permit rebuild against Python 2.5.

* Wed Nov 01 2006 Lev Givon <lev@mandriva.org> 0.5.1-2mdv2007.1
+ Revision: 75027
- Raise release number to placate build system.
- Update to 0.5.1.
- Import python-scipy

* Mon Jul 31 2006 Lev Givon <lev@mandriva.org> 0.5.0-1mdk
- Update.

* Fri May 26 2006 Lev Givon <lev@mandriva.org> 0.4.9-2mdk
- More cleanup.

* Thu May 25 2006 Lev Givon <lev@mandriva.org> 0.4.9-1mdk
- Update version.

* Mon May 22 2006 Lev Givon <lev@mandriva.org> 0.4.8-5mdk
- Make build requirements more concise.

* Sat May 06 2006 Lev Givon <lev@mandriva.org> 0.4.8-4mdk
- Correct license.

* Sat Apr 29 2006 Lev Givon <lev@mandriva.org> 0.4.8-3mdk
- Fix build requirements, build with -fPIC

* Fri Apr 28 2006 Lev Givon <lev@mandriva.org> 0.4.8-2mdk
- Patch signaltools.py bug

* Sun Mar 19 2006 Lev Givon <lev@mandriva.org> 0.4.8-1mdk
- Update version.

* Thu Feb 23 2006 Lev Givon <lev@mandriva.org> 0.4.6-1mdk
- Update version, fine-tune spec file.

* Tue Jan 31 2006 Lev Givon <lev@mandriva.org> 0.4.4-1mdk
- Update version.

* Mon Jan 23 2006 Lev Givon <lev@mandriva.org> 0.4.3-1mdk
- Package new SciPy for Mandriva.

* Fri Oct 07 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 0.3.2-3mdk
- finally build on x86_64 !

* Fri Sep 16 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 0.3.2-2mdk
- requires and use gcc3.3-g77

* Thu Mar 31 2005 Gaetan Lehmann <glehmann@n4.mandrakesoft.com> 0.3.2-1mdk
- initial contrib

